# -*- coding: utf-8 -*-
from velamentum.signale.Signal import Signal
from velamentum.multimedia.AudioPlayer import AudioPlayer
from velamentum.dateien.Datei import Datei
import os.path

class AudioSignal(Signal):
    """Die Klasse AudioSignal dient der Übermittlung von Audiosignalen 
    an den Benutzer.
    
    Attribute:
        datei (Datei): Audiodatei, die für das Signal verwendet werden soll.
    """

    def __init__(self, pDatei=None):
        """Konstruktor. Initialisiert das AudioSignal.
        
        Parameter:
            [optional] pDatei (Zeichenkette): Audiodatei, die für das Signal
                verwendet werden soll. [Standardwert: None]
        """
        Signal.__init__(self)
        self.setzeDatei(pDatei)
        self.__audioPlayer = AudioPlayer(self.nenneDatei())

    def nenneDatei(self):
        """Anfrage. Gibt die Audiodatei des Signals zurück.
        
        Parameter:
            --- keine ---
            
        Rückgabe (Zeichenkette): Audiodatei des Signals.
        """
        return self.__datei
        
    def setzeDatei(self, pDatei):
        """Auftrag. Ändert die Audiodatei des Signals.
        
        Parameter:
            pDatei (Zeichenkette): Audiodatei des Signals.        
        """ 
        # Falls keine Datei angegeben wurde, verwende Standarddatei aus dem
        # Modulpfad.
        if pDatei==None:
            tDatei = os.path.join(os.path.dirname(__file__),"AudioSignal.mp3")
            pDatei = Datei(tDatei)
        
        self.__datei = pDatei
        
    def signalisiere(self):
        """Auftrag. Übermittelt das Signal an den Benutzer.
        
        Parameter 
            --- keine ---
        """
        self.__audioPlayer.wiedergeben()
        
    # Attribute (verdeckte Getter und Setter)
    datei = property(nenneDatei, setzeDatei, doc="Die Audiodatei, die für das "\
        "Signal verwendet werden soll.")
