# -*- coding: utf-8 -*-
from velamentum.signale.Signal import Signal
import dialogs

class VibrationsSignal(Signal):
    """Die Klasse Signal dient der Übermittlung von Vibrationssignalen
    an den Benutzer.
    
    Attribute
        dauer (Zahl): Dauer der Vibration in Millisekunden."""

    def __init__(self, pDauer=300):
        """Konstruktor. Initialisiert das Vibrationssignal.
        
        Parameter:
            [optional] pDauer (Zahl): Dauer der Vibration in Millisekunden.
                [Standardwert: 300]
        """
        Signal.__init__(self)
        self.dauer = pDauer

    def nenneDauer(self):
        """Anfrage. Gibt die Dauer der Vibration zurück.
        
        Parameter:
            --- keine ---
        
        Rückgabe (Zahl): Dauer der Vibration in Millisekunden.
        """
        return self.dauer
        
    def setzeDauer(self, pDauer):
        """Auftrag. Ändert die Dauer der Vibration.
        
        Parameter:
            pDauer: Dauer der Vibration in Millisekunden.
        """
        self.dauer = pDauer
        
    def signalisiere(self):
        """Auftrag. Übermittelt das Signal an den Benutzer.
        
        Parameter:
            --- keine ---
        """
        dialogs.alert('Fehler', 'Für iOS nicht implementiert.')
